summaryrefslogtreecommitdiff
path: root/lang
diff options
context:
space:
mode:
authorjlam <jlam@pkgsrc.org>1999-10-12 08:01:33 +0000
committerjlam <jlam@pkgsrc.org>1999-10-12 08:01:33 +0000
commit45ef1508d3d4f402cff80f457acae63741d4c8a6 (patch)
tree3d7e90f2b4ee8084dfc137ffa917358dc225bc4f /lang
parent49816912727c2df50a6d958f040eaeaff5926f13 (diff)
downloadpkgsrc-45ef1508d3d4f402cff80f457acae63741d4c8a6.tar.gz
* Rearrange directory structure to conform to hier(7);
* Add ability to load personal Eiffel environment via ${HOME}/.smalleiffelrc when using the compiler system.
Diffstat (limited to 'lang')
-rw-r--r--lang/smalleiffel/Makefile88
-rw-r--r--lang/smalleiffel/files/compiler.se2
-rw-r--r--lang/smalleiffel/files/loadpath.UNIX3
-rw-r--r--lang/smalleiffel/files/md52
-rw-r--r--lang/smalleiffel/files/patch-sum4
-rw-r--r--lang/smalleiffel/files/smalleiffel.sh22
-rw-r--r--lang/smalleiffel/patches/patch-aa13
-rw-r--r--lang/smalleiffel/patches/patch-ab13
-rw-r--r--lang/smalleiffel/pkg/COMMENT2
-rw-r--r--lang/smalleiffel/pkg/DESCR4
-rw-r--r--lang/smalleiffel/pkg/PLIST1432
11 files changed, 820 insertions, 765 deletions
diff --git a/lang/smalleiffel/Makefile b/lang/smalleiffel/Makefile
index ae329a8bc1c..1c09bce3049 100644
--- a/lang/smalleiffel/Makefile
+++ b/lang/smalleiffel/Makefile
@@ -1,12 +1,12 @@
-# $NetBSD: Makefile,v 1.2 1999/06/21 21:23:15 jlam Exp $
+# $NetBSD: Makefile,v 1.3 1999/10/12 08:01:33 jlam Exp $
#
DISTNAME= se
PKGNAME= smalleiffel-0.78
WRKSRC= ${WRKDIR}/SmallEiffel
CATEGORIES= lang
-MASTER_SITES= ftp://ftp.cs.rit.edu/pub/mirrors/SmallEiffel/ \
- ftp://ftp.loria.fr/pub/loria/genielog/SmallEiffel/ \
+MASTER_SITES= ftp://ftp.loria.fr/pub/loria/genielog/SmallEiffel/ \
+ ftp://ftp.cs.rit.edu/pub/mirrors/SmallEiffel/ \
ftp://ftp.progsoc.uts.edu.au/pub/Eiffel/SmallEiffel/ \
ftp://gd.tuwien.ac.at/pub/languages/SmallEiffel/
EXTRACT_SUFX= .tgz
@@ -14,38 +14,72 @@ EXTRACT_SUFX= .tgz
MAINTAINER= jlam@netbsd.org
HOMEPAGE= http://smalleiffel.loria.fr/
-SE?= ${PREFIX}/lib/smalleiffel
+DOCDIR= ${PREFIX}/share/doc/smalleiffel
+EGDIR= ${PREFIX}/share/examples/smalleiffel
+LIBDIR= ${PREFIX}/share/smalleiffel
+LIBEXECDIR= ${PREFIX}/libexec/smalleiffel
+
BINNAME= smalleiffel
+SE_BINARIES= clean compile compile_to_c compile_to_jvm \
+ finder pretty print_jvm_class short
post-extract:
- ( cd ${WRKSRC}/sys; ${RM} compiler.se gc loadpath.* system.se )
- ( cd ${FILESDIR}; \
- ${CP} compiler.se gc loadpath.UNIX system.se ${WRKSRC}/sys )
find ${WRKSRC} -type f -print | xargs ${CHMOD} 644
+ find ${WRKSRC} -name ".gdb*" -print | xargs ${RM} -f
+ cd ${WRKSRC}/man; ${RM} -f *.txt
+ cd ${WRKSRC}/sys; ${RM} -f compiler.se gc loadpath.* system.se
+ cd ${FILESDIR}; \
+ ${CP} -f compiler.se gc loadpath.UNIX system.se ${WRKSRC}/sys
+
+post-patch:
+ cd ${WRKSRC}/lib_se; \
+ ${RM} -f frozen_string_list.e.orig system_tools.e.orig
do-build:
- ( cd ${WRKSRC}/bin_c; \
- for f in clean compile compile_to_c compile_to_jvm \
- finder pretty print_jvm_class short; \
- do \
- ${ECHO} Building $$f...; \
- ${SH} -x $$f.make; \
- ${CP} -f ${WRKSRC}/bin_c/$$f ${WRKSRC}/bin/$$f; \
- done )
- ${SED} -e "s,@@SE@@,${SE},g" \
- <${FILESDIR}/${BINNAME}.sh >${WRKDIR}/${BINNAME}.sh
+ @${ECHO} '*** Building Eiffel compiler system (pass 1) ***'
+ @cd ${WRKSRC}/bin_c; \
+ for file in ${SE_BINARIES}; do \
+ ${ECHO} Building $$file...; \
+ ${SH} $$file.make; \
+ ${CP} -f ${WRKSRC}/bin_c/$$file ${WRKSRC}/bin/$$file; \
+ done; \
+ ${RM} -f *
-do-install:
- ${INSTALL_DATA_DIR} ${SE}
- for d in bin contrib lib_rand lib_se lib_show lib_std man \
- short sys; do \
- ( cd ${WRKSRC}; ${GTAR} cf - $$d ) \
- | ( cd ${SE}; ${GTAR} xvf - ); \
+ @${ECHO} '*** Building Eiffel compiler system (pass 2) ***'
+ @cd ${WRKSRC}/bin_c; \
+ for file in ${SE_BINARIES}; do \
+ ${ECHO} Building $$file...; \
+ SMALLEIFFEL=${WRKSRC} SmallEiffel=${WRKSRC}/sys/system.se \
+ ../bin/compile -boost -no_split -o $$file $$file; \
done
- ${CHOWN} -R ${LIBOWN}:${LIBGRP} ${SE}
- ${CHOWN} -R ${BINOWN}:${BINGRP} ${SE}/bin
- ${INSTALL_DATA} ${WRKSRC}/COPYING ${WRKSRC}/READ_ME ${SE}
- ${INSTALL_DATA} ${WRKSRC}/misc/NOT_YET_IMPLEMENTED.* ${SE}/man
+
+post-build:
+ ${SED} -e "s,@@SE_LIB@@,${LIBDIR},g" \
+ -e "s,@@SE_LIBEXEC@@,${LIBEXECDIR},g" \
+ ${FILESDIR}/${BINNAME}.sh > ${WRKDIR}/${BINNAME}.sh
+
+do-install:
${INSTALL_SCRIPT} ${WRKDIR}/${BINNAME}.sh ${PREFIX}/bin/${BINNAME}
+ ${INSTALL_PROGRAM_DIR} ${LIBEXECDIR}
+ for file in ${SE_BINARIES}; do \
+ ${INSTALL_PROGRAM} ${WRKSRC}/bin_c/$$file ${LIBEXECDIR}; \
+ done
+ ${INSTALL_DATA_DIR} ${LIBDIR}
+ cd ${WRKSRC}; \
+ for dir in lib_rand lib_se lib_std short sys; do \
+ ${PAX} -rw $$dir ${LIBDIR}; \
+ done
+ ${CHOWN} -R ${SHAREOWN}:${SHAREGRP} ${LIBDIR}
+ ${INSTALL_DATA_DIR} ${DOCDIR}
+ ${INSTALL_DATA} ${WRKSRC}/COPYING ${DOCDIR}
+ ${INSTALL_DATA} ${WRKSRC}/misc/NOT_YET_IMPLEMENTED.txt ${DOCDIR}
+ ${INSTALL_DATA} ${WRKSRC}/misc/WeNeedFeedBack.txt ${DOCDIR}
+ cd ${WRKSRC}/man; ${INSTALL_DATA} *.html *.gif *.FAQ ${DOCDIR}
+ ${INSTALL_DATA_DIR} ${EGDIR}
+ cd ${WRKSRC}; \
+ for dir in contrib lib_show; do \
+ ${PAX} -rw $$dir ${EGDIR}; \
+ done
+ ${CHOWN} -R ${SHAREOWN}:${SHAREGRP} ${EGDIR}
.include "../../mk/bsd.pkg.mk"
diff --git a/lang/smalleiffel/files/compiler.se b/lang/smalleiffel/files/compiler.se
index 8724cd23bc0..5824b77767c 100644
--- a/lang/smalleiffel/files/compiler.se
+++ b/lang/smalleiffel/files/compiler.se
@@ -1 +1 @@
-cc
+gcc
diff --git a/lang/smalleiffel/files/loadpath.UNIX b/lang/smalleiffel/files/loadpath.UNIX
index 1e3bbcc0329..b9262a3691d 100644
--- a/lang/smalleiffel/files/loadpath.UNIX
+++ b/lang/smalleiffel/files/loadpath.UNIX
@@ -1,5 +1,4 @@
-./
${SMALLEIFFEL}/lib_std/
${SMALLEIFFEL}/lib_rand/
${SMALLEIFFEL}/lib_show/
-${SMALLEIFFEL}/lib_se/ \ No newline at end of file
+${SMALLEIFFEL}/lib_se/
diff --git a/lang/smalleiffel/files/md5 b/lang/smalleiffel/files/md5
index d6d886d417d..2fcc1c2aa76 100644
--- a/lang/smalleiffel/files/md5
+++ b/lang/smalleiffel/files/md5
@@ -1,3 +1,3 @@
-$NetBSD: md5,v 1.2 1999/06/21 21:23:16 jlam Exp $
+$NetBSD: md5,v 1.3 1999/10/12 08:01:33 jlam Exp $
MD5 (se.tgz) = e0e8fce1b0b277a00c98ff83e1da06da
diff --git a/lang/smalleiffel/files/patch-sum b/lang/smalleiffel/files/patch-sum
new file mode 100644
index 00000000000..15aaea31867
--- /dev/null
+++ b/lang/smalleiffel/files/patch-sum
@@ -0,0 +1,4 @@
+$NetBSD: patch-sum,v 1.1 1999/10/12 08:01:33 jlam Exp $
+
+MD5 (patch-aa) = 3c747a451b17b116bdf5a16e68a3a0fb
+MD5 (patch-ab) = 99935df366c8a24e4569e969a356c209
diff --git a/lang/smalleiffel/patches/patch-aa b/lang/smalleiffel/patches/patch-aa
new file mode 100644
index 00000000000..ca59c5ce053
--- /dev/null
+++ b/lang/smalleiffel/patches/patch-aa
@@ -0,0 +1,13 @@
+$NetBSD: patch-aa,v 1.1 1999/10/12 08:01:33 jlam Exp $
+
+--- lib_se/frozen_string_list.e.orig Sat Jun 5 14:51:11 1999
++++ lib_se/frozen_string_list.e Mon Jun 28 04:00:01 1999
+@@ -111,7 +111,7 @@
+ -----------------------------------------------------------------------------
+ -- Frozen list of other names :
+
+- fz_bin: STRING is "bin";
++ fz_bin: STRING is "libexec/smalleiffel";
+ fz_bit_foo: STRING is "BIT ";
+ fz_char: STRING is "char";
+ fz_close_c_comment: STRING is "*/";
diff --git a/lang/smalleiffel/patches/patch-ab b/lang/smalleiffel/patches/patch-ab
new file mode 100644
index 00000000000..a972e7c73ba
--- /dev/null
+++ b/lang/smalleiffel/patches/patch-ab
@@ -0,0 +1,13 @@
+$NetBSD: patch-ab,v 1.1 1999/10/12 08:01:34 jlam Exp $
+
+--- lib_se/system_tools.e.orig Sat Jun 5 14:51:08 1999
++++ lib_se/system_tools.e Mon Jun 28 04:05:27 1999
+@@ -211,6 +211,8 @@
+ tmp_file_read.disconnect;
+ bin_directory := sys_directory.twin;
+ parent_directory(bin_directory);
++ parent_directory(bin_directory);
++ parent_directory(bin_directory);
+ add_directory(bin_directory,fz_bin);
+ end;
+
diff --git a/lang/smalleiffel/pkg/COMMENT b/lang/smalleiffel/pkg/COMMENT
index 956e2a3284c..6edfdacb1b0 100644
--- a/lang/smalleiffel/pkg/COMMENT
+++ b/lang/smalleiffel/pkg/COMMENT
@@ -1 +1 @@
-The GNU Eiffel Compiler.
+GNU Eiffel compiler
diff --git a/lang/smalleiffel/pkg/DESCR b/lang/smalleiffel/pkg/DESCR
index 7cdf8d0af89..f32b9a02843 100644
--- a/lang/smalleiffel/pkg/DESCR
+++ b/lang/smalleiffel/pkg/DESCR
@@ -6,5 +6,5 @@ The current distribution included an Eiffel to C compiler, an Eiffel
to Java bytecode compiler, a documentation tool, a pretty printer,
and various other tools.
-Please note: version numbers are negative; -0.89, for
-example, is newer than -0.91
+Please note: version numbers are negative; -0.89, for example, is newer
+than -0.91
diff --git a/lang/smalleiffel/pkg/PLIST b/lang/smalleiffel/pkg/PLIST
index bfc59961606..19c6ce90b1c 100644
--- a/lang/smalleiffel/pkg/PLIST
+++ b/lang/smalleiffel/pkg/PLIST
@@ -1,726 +1,708 @@
-@comment $NetBSD: PLIST,v 1.2 1999/06/21 21:23:16 jlam Exp $
+@comment $NetBSD: PLIST,v 1.3 1999/10/12 08:01:34 jlam Exp $
bin/smalleiffel
-lib/smalleiffel/COPYING
-lib/smalleiffel/READ_ME
-lib/smalleiffel/bin/clean
-lib/smalleiffel/bin/compile
-lib/smalleiffel/bin/compile_to_c
-lib/smalleiffel/bin/compile_to_jvm
-lib/smalleiffel/bin/finder
-lib/smalleiffel/bin/pretty
-lib/smalleiffel/bin/print_jvm_class
-lib/smalleiffel/bin/short
-lib/smalleiffel/contrib/READ_ME
-lib/smalleiffel/contrib/edb/READ_ME
-lib/smalleiffel/contrib/edb/add-line-directive
-lib/smalleiffel/contrib/edb/edb.el
-lib/smalleiffel/contrib/edb/edb19.el
-lib/smalleiffel/contrib/edb/gc-inc
-lib/smalleiffel/contrib/edb/move-if-changed
-lib/smalleiffel/contrib/edb/sec
-lib/smalleiffel/contrib/htmldoc/READ_ME
-lib/smalleiffel/contrib/htmldoc/hooks.sh
-lib/smalleiffel/contrib/htmldoc/htmlshort
-lib/smalleiffel/contrib/lib/case_insensitive_string.e
-lib/smalleiffel/contrib/lib/header.txt
-lib/smalleiffel/contrib/lib/string_formatter.e
-lib/smalleiffel/lib_rand/READ_ME
-lib/smalleiffel/lib_rand/gen_rand.e
-lib/smalleiffel/lib_rand/min_stand.e
-lib/smalleiffel/lib_rand/std_rand.e
-lib/smalleiffel/lib_se/abstract_current.e
-lib/smalleiffel/lib_se/abstract_result.e
-lib/smalleiffel/lib_se/address_of.e
-lib/smalleiffel/lib_se/address_of_pool.e
-lib/smalleiffel/lib_se/aliased_string_list.e
-lib/smalleiffel/lib_se/argument_name.e
-lib/smalleiffel/lib_se/argument_name1.e
-lib/smalleiffel/lib_se/argument_name2.e
-lib/smalleiffel/lib_se/assertion.e
-lib/smalleiffel/lib_se/assertion_collector.e
-lib/smalleiffel/lib_se/assertion_list.e
-lib/smalleiffel/lib_se/assignment.e
-lib/smalleiffel/lib_se/attribute.e
-lib/smalleiffel/lib_se/base_class.e
-lib/smalleiffel/lib_se/base_type_constant.e
-lib/smalleiffel/lib_se/binary_file_read.e
-lib/smalleiffel/lib_se/binary_file_write.e
-lib/smalleiffel/lib_se/bit_constant.e
-lib/smalleiffel/lib_se/boolean_constant.e
-lib/smalleiffel/lib_se/c_pretty_printer.e
-lib/smalleiffel/lib_se/call.e
-lib/smalleiffel/lib_se/call_0.e
-lib/smalleiffel/lib_se/call_0_c.e
-lib/smalleiffel/lib_se/call_1.e
-lib/smalleiffel/lib_se/call_1_c.e
-lib/smalleiffel/lib_se/call_infix.e
-lib/smalleiffel/lib_se/call_infix1.e
-lib/smalleiffel/lib_se/call_infix2.e
-lib/smalleiffel/lib_se/call_infix_and.e
-lib/smalleiffel/lib_se/call_infix_and_then.e
-lib/smalleiffel/lib_se/call_infix_div.e
-lib/smalleiffel/lib_se/call_infix_eq.e
-lib/smalleiffel/lib_se/call_infix_freeop.e
-lib/smalleiffel/lib_se/call_infix_ge.e
-lib/smalleiffel/lib_se/call_infix_gt.e
-lib/smalleiffel/lib_se/call_infix_implies.e
-lib/smalleiffel/lib_se/call_infix_int_div.e
-lib/smalleiffel/lib_se/call_infix_int_rem.e
-lib/smalleiffel/lib_se/call_infix_le.e
-lib/smalleiffel/lib_se/call_infix_lt.e
-lib/smalleiffel/lib_se/call_infix_minus.e
-lib/smalleiffel/lib_se/call_infix_neq.e
-lib/smalleiffel/lib_se/call_infix_or.e
-lib/smalleiffel/lib_se/call_infix_or_else.e
-lib/smalleiffel/lib_se/call_infix_plus.e
-lib/smalleiffel/lib_se/call_infix_power.e
-lib/smalleiffel/lib_se/call_infix_times.e
-lib/smalleiffel/lib_se/call_infix_xor.e
-lib/smalleiffel/lib_se/call_n.e
-lib/smalleiffel/lib_se/call_prefix.e
-lib/smalleiffel/lib_se/call_prefix_freeop.e
-lib/smalleiffel/lib_se/call_prefix_minus.e
-lib/smalleiffel/lib_se/call_prefix_not.e
-lib/smalleiffel/lib_se/call_prefix_plus.e
-lib/smalleiffel/lib_se/call_proc_call.e
-lib/smalleiffel/lib_se/cecil_arg_list.e
-lib/smalleiffel/lib_se/cecil_pool.e
-lib/smalleiffel/lib_se/cecil_target.e
-lib/smalleiffel/lib_se/character_constant.e
-lib/smalleiffel/lib_se/check_invariant.e
-lib/smalleiffel/lib_se/class_invariant.e
-lib/smalleiffel/lib_se/class_name.e
-lib/smalleiffel/lib_se/class_name_list.e
-lib/smalleiffel/lib_se/clean.e
-lib/smalleiffel/lib_se/client_list.e
-lib/smalleiffel/lib_se/code_attribute.e
-lib/smalleiffel/lib_se/code_printer.e
-lib/smalleiffel/lib_se/command_flags.e
-lib/smalleiffel/lib_se/comment.e
-lib/smalleiffel/lib_se/compile.e
-lib/smalleiffel/lib_se/compile_to_c.e
-lib/smalleiffel/lib_se/compile_to_jvm.e
-lib/smalleiffel/lib_se/compound.e
-lib/smalleiffel/lib_se/constant_pool.e
-lib/smalleiffel/lib_se/cp_info.e
-lib/smalleiffel/lib_se/cp_info_tags.e
-lib/smalleiffel/lib_se/creation_call.e
-lib/smalleiffel/lib_se/creation_call_1.e
-lib/smalleiffel/lib_se/creation_call_1_2.e
-lib/smalleiffel/lib_se/creation_call_2.e
-lib/smalleiffel/lib_se/creation_call_2_4.e
-lib/smalleiffel/lib_se/creation_call_3.e
-lib/smalleiffel/lib_se/creation_call_3_4.e
-lib/smalleiffel/lib_se/creation_call_4.e
-lib/smalleiffel/lib_se/creation_clause.e
-lib/smalleiffel/lib_se/creation_clause_list.e
-lib/smalleiffel/lib_se/cst_att.e
-lib/smalleiffel/lib_se/cst_att_bit.e
-lib/smalleiffel/lib_se/cst_att_boolean.e
-lib/smalleiffel/lib_se/cst_att_character.e
-lib/smalleiffel/lib_se/cst_att_double.e
-lib/smalleiffel/lib_se/cst_att_integer.e
-lib/smalleiffel/lib_se/cst_att_real.e
-lib/smalleiffel/lib_se/cst_att_string.e
-lib/smalleiffel/lib_se/cst_att_unique.e
-lib/smalleiffel/lib_se/declaration.e
-lib/smalleiffel/lib_se/declaration_1.e
-lib/smalleiffel/lib_se/declaration_group.e
-lib/smalleiffel/lib_se/declaration_list.e
-lib/smalleiffel/lib_se/deferred_function.e
-lib/smalleiffel/lib_se/deferred_procedure.e
-lib/smalleiffel/lib_se/deferred_routine.e
-lib/smalleiffel/lib_se/e_check.e
-lib/smalleiffel/lib_se/e_debug.e
-lib/smalleiffel/lib_se/e_ensure.e
-lib/smalleiffel/lib_se/e_false.e
-lib/smalleiffel/lib_se/e_feature.e
-lib/smalleiffel/lib_se/e_inspect.e
-lib/smalleiffel/lib_se/e_loop.e
-lib/smalleiffel/lib_se/e_old.e
-lib/smalleiffel/lib_se/e_precursor.e
-lib/smalleiffel/lib_se/e_precursor_function.e
-lib/smalleiffel/lib_se/e_precursor_procedure.e
-lib/smalleiffel/lib_se/e_require.e
-lib/smalleiffel/lib_se/e_retry.e
-lib/smalleiffel/lib_se/e_strip.e
-lib/smalleiffel/lib_se/e_true.e
-lib/smalleiffel/lib_se/e_void.e
-lib/smalleiffel/lib_se/e_when.e
-lib/smalleiffel/lib_se/echo.e
-lib/smalleiffel/lib_se/effective_arg_list.e
-lib/smalleiffel/lib_se/effective_routine.e
-lib/smalleiffel/lib_se/eiffel_parser.e
-lib/smalleiffel/lib_se/error_handler.e
-lib/smalleiffel/lib_se/exception_table.e
-lib/smalleiffel/lib_se/exceptions_handler.e
-lib/smalleiffel/lib_se/export_item.e
-lib/smalleiffel/lib_se/export_list.e
-lib/smalleiffel/lib_se/expression.e
-lib/smalleiffel/lib_se/expression_with_comment.e
-lib/smalleiffel/lib_se/external_function.e
-lib/smalleiffel/lib_se/external_procedure.e
-lib/smalleiffel/lib_se/external_routine.e
-lib/smalleiffel/lib_se/feature_clause.e
-lib/smalleiffel/lib_se/feature_clause_list.e
-lib/smalleiffel/lib_se/feature_name.e
-lib/smalleiffel/lib_se/feature_name_list.e
-lib/smalleiffel/lib_se/field_info.e
-lib/smalleiffel/lib_se/finder.e
-lib/smalleiffel/lib_se/fmt.e
-lib/smalleiffel/lib_se/formal_arg_list.e
-lib/smalleiffel/lib_se/formal_generic_arg.e
-lib/smalleiffel/lib_se/formal_generic_list.e
-lib/smalleiffel/lib_se/frozen_feature_name.e
-lib/smalleiffel/lib_se/frozen_string_list.e
-lib/smalleiffel/lib_se/function.e
-lib/smalleiffel/lib_se/gc_handler.e
-lib/smalleiffel/lib_se/globals.e
-lib/smalleiffel/lib_se/id_provider.e
-lib/smalleiffel/lib_se/if_globals.e
-lib/smalleiffel/lib_se/ifthen.e
-lib/smalleiffel/lib_se/ifthenelse.e
-lib/smalleiffel/lib_se/ifthenlist.e
-lib/smalleiffel/lib_se/implicit_cast.e
-lib/smalleiffel/lib_se/implicit_current.e
-lib/smalleiffel/lib_se/index_clause.e
-lib/smalleiffel/lib_se/index_list.e
-lib/smalleiffel/lib_se/infix_name.e
-lib/smalleiffel/lib_se/install.e
-lib/smalleiffel/lib_se/instruction.e
-lib/smalleiffel/lib_se/instruction_with_comment.e
-lib/smalleiffel/lib_se/integer_constant.e
-lib/smalleiffel/lib_se/jvm.e
-lib/smalleiffel/lib_se/local_argument.e
-lib/smalleiffel/lib_se/local_argument1.e
-lib/smalleiffel/lib_se/local_name.e
-lib/smalleiffel/lib_se/local_name1.e
-lib/smalleiffel/lib_se/local_name2.e
-lib/smalleiffel/lib_se/local_var_list.e
-lib/smalleiffel/lib_se/loop_invariant.e
-lib/smalleiffel/lib_se/loop_variant.e
-lib/smalleiffel/lib_se/loop_variant_1.e
-lib/smalleiffel/lib_se/loop_variant_2.e
-lib/smalleiffel/lib_se/manifest_array.e
-lib/smalleiffel/lib_se/manifest_array_pool.e
-lib/smalleiffel/lib_se/manifest_string.e
-lib/smalleiffel/lib_se/manifest_string_pool.e
-lib/smalleiffel/lib_se/method_info.e
-lib/smalleiffel/lib_se/name.e
-lib/smalleiffel/lib_se/native.e
-lib/smalleiffel/lib_se/native_c.e
-lib/smalleiffel/lib_se/native_inline_with_current.e
-lib/smalleiffel/lib_se/native_inline_without_current.e
-lib/smalleiffel/lib_se/native_jvm.e
-lib/smalleiffel/lib_se/native_jvm_invokestatic.e
-lib/smalleiffel/lib_se/native_jvm_invokevirtual.e
-lib/smalleiffel/lib_se/native_small_eiffel.e
-lib/smalleiffel/lib_se/native_with_current.e
-lib/smalleiffel/lib_se/native_without_current.e
-lib/smalleiffel/lib_se/once_function.e
-lib/smalleiffel/lib_se/once_procedure.e
-lib/smalleiffel/lib_se/once_result.e
-lib/smalleiffel/lib_se/once_routine.e
-lib/smalleiffel/lib_se/once_routine_pool.e
-lib/smalleiffel/lib_se/ordinary_result.e
-lib/smalleiffel/lib_se/parent.e
-lib/smalleiffel/lib_se/parent_list.e
-lib/smalleiffel/lib_se/parser_buffer.e
-lib/smalleiffel/lib_se/position.e
-lib/smalleiffel/lib_se/precursor_name.e
-lib/smalleiffel/lib_se/prefix_name.e
-lib/smalleiffel/lib_se/pretty.e
-lib/smalleiffel/lib_se/print_jvm_class.e
-lib/smalleiffel/lib_se/proc_call.e
-lib/smalleiffel/lib_se/proc_call_0.e
-lib/smalleiffel/lib_se/proc_call_1.e
-lib/smalleiffel/lib_se/proc_call_n.e
-lib/smalleiffel/lib_se/procedure.e
-lib/smalleiffel/lib_se/real_constant.e
-lib/smalleiffel/lib_se/rename_list.e
-lib/smalleiffel/lib_se/rename_pair.e
-lib/smalleiffel/lib_se/reverse_assignment.e
-lib/smalleiffel/lib_se/routine.e
-lib/smalleiffel/lib_se/run_class.e
-lib/smalleiffel/lib_se/run_control.e
-lib/smalleiffel/lib_se/run_feature.e
-lib/smalleiffel/lib_se/run_feature_1.e
-lib/smalleiffel/lib_se/run_feature_10.e
-lib/smalleiffel/lib_se/run_feature_11.e
-lib/smalleiffel/lib_se/run_feature_2.e
-lib/smalleiffel/lib_se/run_feature_3.e
-lib/smalleiffel/lib_se/run_feature_4.e
-lib/smalleiffel/lib_se/run_feature_5.e
-lib/smalleiffel/lib_se/run_feature_6.e
-lib/smalleiffel/lib_se/run_feature_7.e
-lib/smalleiffel/lib_se/run_feature_8.e
-lib/smalleiffel/lib_se/run_feature_9.e
-lib/smalleiffel/lib_se/run_require.e
-lib/smalleiffel/lib_se/same_executables.e
-lib/smalleiffel/lib_se/short.e
-lib/smalleiffel/lib_se/short_print.e
-lib/smalleiffel/lib_se/simple_feature_name.e
-lib/smalleiffel/lib_se/small_eiffel.e
-lib/smalleiffel/lib_se/string_aliaser.e
-lib/smalleiffel/lib_se/switch.e
-lib/smalleiffel/lib_se/switch_collection.e
-lib/smalleiffel/lib_se/system_tools.e
-lib/smalleiffel/lib_se/tag_name.e
-lib/smalleiffel/lib_se/tmp_feature.e
-lib/smalleiffel/lib_se/tmp_name.e
-lib/smalleiffel/lib_se/type.e
-lib/smalleiffel/lib_se/type_anchored.e
-lib/smalleiffel/lib_se/type_any.e
-lib/smalleiffel/lib_se/type_array.e
-lib/smalleiffel/lib_se/type_basic_eiffel_expanded.e
-lib/smalleiffel/lib_se/type_bit.e
-lib/smalleiffel/lib_se/type_bit_1.e
-lib/smalleiffel/lib_se/type_bit_2.e
-lib/smalleiffel/lib_se/type_bit_ref.e
-lib/smalleiffel/lib_se/type_boolean.e
-lib/smalleiffel/lib_se/type_character.e
-lib/smalleiffel/lib_se/type_class.e
-lib/smalleiffel/lib_se/type_double.e
-lib/smalleiffel/lib_se/type_expanded.e
-lib/smalleiffel/lib_se/type_formal_generic.e
-lib/smalleiffel/lib_se/type_generic.e
-lib/smalleiffel/lib_se/type_integer.e
-lib/smalleiffel/lib_se/type_like_argument.e
-lib/smalleiffel/lib_se/type_like_current.e
-lib/smalleiffel/lib_se/type_like_feature.e
-lib/smalleiffel/lib_se/type_native_array.e
-lib/smalleiffel/lib_se/type_none.e
-lib/smalleiffel/lib_se/type_pointer.e
-lib/smalleiffel/lib_se/type_real.e
-lib/smalleiffel/lib_se/type_ref_to_exp.e
-lib/smalleiffel/lib_se/type_string.e
-lib/smalleiffel/lib_se/when_item.e
-lib/smalleiffel/lib_se/when_item_1.e
-lib/smalleiffel/lib_se/when_item_2.e
-lib/smalleiffel/lib_se/when_list.e
-lib/smalleiffel/lib_se/writable_attribute.e
-lib/smalleiffel/lib_se/written_current.e
-lib/smalleiffel/lib_show/animal/animal.e
-lib/smalleiffel/lib_show/animal/chat.e
-lib/smalleiffel/lib_show/animal/chien.e
-lib/smalleiffel/lib_show/animal/mille_pattes.e
-lib/smalleiffel/lib_show/animal/quadrupede.e
-lib/smalleiffel/lib_show/animal/sample1.e
-lib/smalleiffel/lib_show/animal/sample2.e
-lib/smalleiffel/lib_show/animal/sample3.e
-lib/smalleiffel/lib_show/cecil/JVM/Example1.java
-lib/smalleiffel/lib_show/cecil/JVM/Example2.java
-lib/smalleiffel/lib_show/cecil/JVM/Example3.java
-lib/smalleiffel/lib_show/cecil/JVM/Example4.java
-lib/smalleiffel/lib_show/cecil/JVM/root2.e
-lib/smalleiffel/lib_show/cecil/JVM/root3.e
-lib/smalleiffel/lib_show/cecil/JVM/root4.e
-lib/smalleiffel/lib_show/cecil/READ_ME
-lib/smalleiffel/lib_show/cecil/example1/.gdb_history
-lib/smalleiffel/lib_show/cecil/example1/c_prog.c
-lib/smalleiffel/lib_show/cecil/example1/cecil.se
-lib/smalleiffel/lib_show/cecil/example1/example.e
-lib/smalleiffel/lib_show/cecil/example1/output
-lib/smalleiffel/lib_show/cecil/example2/c_prog.c
-lib/smalleiffel/lib_show/cecil/example2/cecil.se
-lib/smalleiffel/lib_show/cecil/example2/example.e
-lib/smalleiffel/lib_show/cecil/example2/output
-lib/smalleiffel/lib_show/cecil/example3/c_prog.c
-lib/smalleiffel/lib_show/cecil/example3/cecil.se
-lib/smalleiffel/lib_show/cecil/example3/example.e
-lib/smalleiffel/lib_show/cecil/example3/output
-lib/smalleiffel/lib_show/cecil/example4/.gdb_history
-lib/smalleiffel/lib_show/cecil/example4/animal.e
-lib/smalleiffel/lib_show/cecil/example4/c_prog.c
-lib/smalleiffel/lib_show/cecil/example4/cat.e
-lib/smalleiffel/lib_show/cecil/example4/cecil.se
-lib/smalleiffel/lib_show/cecil/example4/dog.e
-lib/smalleiffel/lib_show/cecil/example4/example.e
-lib/smalleiffel/lib_show/cecil/example4/output
-lib/smalleiffel/lib_show/cecil/example5/c_prog.c
-lib/smalleiffel/lib_show/cecil/example5/cecil.se
-lib/smalleiffel/lib_show/cecil/example5/example.e
-lib/smalleiffel/lib_show/cecil/example5/output
-lib/smalleiffel/lib_show/cecil/example6/c_prog.c
-lib/smalleiffel/lib_show/cecil/example6/cecil.se
-lib/smalleiffel/lib_show/cecil/example6/example.e
-lib/smalleiffel/lib_show/cecil/example6/output
-lib/smalleiffel/lib_show/cecil/example7/c_prog.c
-lib/smalleiffel/lib_show/cecil/example7/cecil.se
-lib/smalleiffel/lib_show/cecil/example7/example.e
-lib/smalleiffel/lib_show/cecil/example7/output
-lib/smalleiffel/lib_show/cecil/example8/c_factory.e
-lib/smalleiffel/lib_show/cecil/example8/c_prog.c
-lib/smalleiffel/lib_show/cecil/example8/cecil.se
-lib/smalleiffel/lib_show/cecil/example8/example.e
-lib/smalleiffel/lib_show/cecil/example8/output
-lib/smalleiffel/lib_show/directory/.gdbinit
-lib/smalleiffel/lib_show/directory/example01.e
-lib/smalleiffel/lib_show/directory/example01.h
-lib/smalleiffel/lib_show/directory/example01.make
-lib/smalleiffel/lib_show/directory/example011.c
-lib/smalleiffel/lib_show/directory/example012.c
-lib/smalleiffel/lib_show/directory/example013.c
-lib/smalleiffel/lib_show/directory/example02.e
-lib/smalleiffel/lib_show/directory/example03.e
-lib/smalleiffel/lib_show/directory/example03.h
-lib/smalleiffel/lib_show/directory/example03.make
-lib/smalleiffel/lib_show/directory/example031.c
-lib/smalleiffel/lib_show/directory/example032.c
-lib/smalleiffel/lib_show/external/C/READ_ME
-lib/smalleiffel/lib_show/external/C/address_of_demo.e
-lib/smalleiffel/lib_show/external/C/address_of_demo.out
-lib/smalleiffel/lib_show/external/C/address_of_src.c
-lib/smalleiffel/lib_show/external/C/external_demo.e
-lib/smalleiffel/lib_show/external/C/external_demo.out
-lib/smalleiffel/lib_show/external/C/external_src.c
-lib/smalleiffel/lib_show/external/JVM/example1.e
-lib/smalleiffel/lib_show/external/JVM/example1.out
-lib/smalleiffel/lib_show/external/JVM/example2.e
-lib/smalleiffel/lib_show/external/JVM/example2.out
-lib/smalleiffel/lib_show/external/READ_ME
-lib/smalleiffel/lib_show/fibonacci.e
-lib/smalleiffel/lib_show/gcd/integer.e
-lib/smalleiffel/lib_show/gcd/test_gcd.e
-lib/smalleiffel/lib_show/hanoi/hanoi.e
-lib/smalleiffel/lib_show/hanoi/tower.e
-lib/smalleiffel/lib_show/hello_world.e
-lib/smalleiffel/lib_show/knight.e
-lib/smalleiffel/lib_show/lib_rand/demo1.e
-lib/smalleiffel/lib_show/lib_rand/demo2.e
-lib/smalleiffel/lib_show/lib_rand/demo3.e
-lib/smalleiffel/lib_show/parking/command.e
-lib/smalleiffel/lib_show/parking/date.e
-lib/smalleiffel/lib_show/parking/level.e
-lib/smalleiffel/lib_show/parking/parking.e
-lib/smalleiffel/lib_show/parking/run_parking.e
-lib/smalleiffel/lib_show/parking/ticket.e
-lib/smalleiffel/lib_show/print_arguments.e
-lib/smalleiffel/lib_show/pyramid.e
-lib/smalleiffel/lib_show/pyramid2.e
-lib/smalleiffel/lib_show/spread_illness.e
-lib/smalleiffel/lib_std/any.e
-lib/smalleiffel/lib_std/arguments.e
-lib/smalleiffel/lib_std/array.e
-lib/smalleiffel/lib_std/array2.e
-lib/smalleiffel/lib_std/arrayed_collection.e
-lib/smalleiffel/lib_std/basic_directory.e
-lib/smalleiffel/lib_std/bit_n.e
-lib/smalleiffel/lib_std/bit_n_ref.e
-lib/smalleiffel/lib_std/bit_string.e
-lib/smalleiffel/lib_std/boolean.e
-lib/smalleiffel/lib_std/boolean_ref.e
-lib/smalleiffel/lib_std/character.e
-lib/smalleiffel/lib_std/character_ref.e
-lib/smalleiffel/lib_std/collection.e
-lib/smalleiffel/lib_std/collection2.e
-lib/smalleiffel/lib_std/collection_sorter.e
-lib/smalleiffel/lib_std/comparable.e
-lib/smalleiffel/lib_std/counter.e
-lib/smalleiffel/lib_std/dictionary.e
-lib/smalleiffel/lib_std/directory.e
-lib/smalleiffel/lib_std/dirent.e
-lib/smalleiffel/lib_std/double.e
-lib/smalleiffel/lib_std/double_ref.e
-lib/smalleiffel/lib_std/exceptions.e
-lib/smalleiffel/lib_std/file_tools.e
-lib/smalleiffel/lib_std/fixed_array.e
-lib/smalleiffel/lib_std/fixed_array2.e
-lib/smalleiffel/lib_std/general.e
-lib/smalleiffel/lib_std/hashable.e
-lib/smalleiffel/lib_std/input_stream.e
-lib/smalleiffel/lib_std/integer.e
-lib/smalleiffel/lib_std/integer_ref.e
-lib/smalleiffel/lib_std/link.e
-lib/smalleiffel/lib_std/link2.e
-lib/smalleiffel/lib_std/link2_list.e
-lib/smalleiffel/lib_std/link_list.e
-lib/smalleiffel/lib_std/linked_collection.e
-lib/smalleiffel/lib_std/linked_list.e
-lib/smalleiffel/lib_std/memo.e
-lib/smalleiffel/lib_std/memory.e
-lib/smalleiffel/lib_std/native_array.e
-lib/smalleiffel/lib_std/numeric.e
-lib/smalleiffel/lib_std/output_stream.e
-lib/smalleiffel/lib_std/platform.e
-lib/smalleiffel/lib_std/pointer.e
-lib/smalleiffel/lib_std/pointer_ref.e
-lib/smalleiffel/lib_std/real.e
-lib/smalleiffel/lib_std/real_ref.e
-lib/smalleiffel/lib_std/reverse_collection_sorter.e
-lib/smalleiffel/lib_std/std_error.e
-lib/smalleiffel/lib_std/std_file_read.e
-lib/smalleiffel/lib_std/std_file_read_write.e
-lib/smalleiffel/lib_std/std_file_write.e
-lib/smalleiffel/lib_std/std_input.e
-lib/smalleiffel/lib_std/std_input_output.e
-lib/smalleiffel/lib_std/std_output.e
-lib/smalleiffel/lib_std/string.e
-lib/smalleiffel/lib_std/two_way_linked_list.e
-lib/smalleiffel/man/Eiffel.FAQ
-lib/smalleiffel/man/NOT_YET_IMPLEMENTED.html
-lib/smalleiffel/man/NOT_YET_IMPLEMENTED.txt
-lib/smalleiffel/man/SmallEiffelFAQ.html
-lib/smalleiffel/man/SmallEiffelFAQ.txt
-lib/smalleiffel/man/c_code.html
-lib/smalleiffel/man/c_code.txt
-lib/smalleiffel/man/cecil.html
-lib/smalleiffel/man/cecil.txt
-lib/smalleiffel/man/clean.html
-lib/smalleiffel/man/clean.txt
-lib/smalleiffel/man/commands.txt
-lib/smalleiffel/man/compile.html
-lib/smalleiffel/man/compile.txt
-lib/smalleiffel/man/compile_to_c.html
-lib/smalleiffel/man/compile_to_c.txt
-lib/smalleiffel/man/compile_to_jvm.html
-lib/smalleiffel/man/compile_to_jvm.txt
-lib/smalleiffel/man/external.html
-lib/smalleiffel/man/external.txt
-lib/smalleiffel/man/finder.html
-lib/smalleiffel/man/finder.txt
-lib/smalleiffel/man/index.html
-lib/smalleiffel/man/pretty.html
-lib/smalleiffel/man/pretty.txt
-lib/smalleiffel/man/print_jvm_class.html
-lib/smalleiffel/man/print_jvm_class.txt
-lib/smalleiffel/man/se-line.gif
-lib/smalleiffel/man/short.html
-lib/smalleiffel/man/short.txt
-lib/smalleiffel/man/support.html
-lib/smalleiffel/man/support.txt
-lib/smalleiffel/man/system.html
-lib/smalleiffel/man/system.txt
-lib/smalleiffel/short/READ_ME
-lib/smalleiffel/short/html1/Acn
-lib/smalleiffel/short/html1/Bcn
-lib/smalleiffel/short/html1/HOOKS.SH
-lib/smalleiffel/short/html1/Mcn
-lib/smalleiffel/short/html1/READ_ME
-lib/smalleiffel/short/html1/cl_quote
-lib/smalleiffel/short/html1/hook000
-lib/smalleiffel/short/html1/hook002
-lib/smalleiffel/short/html1/hook010
-lib/smalleiffel/short/html1/hook011
-lib/smalleiffel/short/html1/hook012
-lib/smalleiffel/short/html1/hook015
-lib/smalleiffel/short/html1/hook018
-lib/smalleiffel/short/html1/hook019
-lib/smalleiffel/short/html1/hook100
-lib/smalleiffel/short/html1/hook200
-lib/smalleiffel/short/html1/hook201
-lib/smalleiffel/short/html1/hook202
-lib/smalleiffel/short/html1/hook204
-lib/smalleiffel/short/html1/hook205
-lib/smalleiffel/short/html1/hook208
-lib/smalleiffel/short/html1/hook310
-lib/smalleiffel/short/html1/hook313
-lib/smalleiffel/short/html1/hook401
-lib/smalleiffel/short/html1/hook402
-lib/smalleiffel/short/html1/hook413
-lib/smalleiffel/short/html1/hook416
-lib/smalleiffel/short/html1/hook427
-lib/smalleiffel/short/html1/hook430
-lib/smalleiffel/short/html1/hook511
-lib/smalleiffel/short/html1/hook513
-lib/smalleiffel/short/html1/hook516
-lib/smalleiffel/short/html1/hook527
-lib/smalleiffel/short/html1/hook530
-lib/smalleiffel/short/html1/hook599
-lib/smalleiffel/short/html1/hook811
-lib/smalleiffel/short/html1/hook813
-lib/smalleiffel/short/html1/hook816
-lib/smalleiffel/short/html1/hook827
-lib/smalleiffel/short/html1/hook830
-lib/smalleiffel/short/html1/hook900
-lib/smalleiffel/short/html1/hook905
-lib/smalleiffel/short/html1/hook999
-lib/smalleiffel/short/html1/op_quote
-lib/smalleiffel/short/html2/!
-lib/smalleiffel/short/html2/Acn
-lib/smalleiffel/short/html2/Bcn
-lib/smalleiffel/short/html2/Current
-lib/smalleiffel/short/html2/HOOKS.SH
-lib/smalleiffel/short/html2/Mcn
-lib/smalleiffel/short/html2/READ_ME
-lib/smalleiffel/short/html2/Result
-lib/smalleiffel/short/html2/Void
-lib/smalleiffel/short/html2/cl_quote
-lib/smalleiffel/short/html2/hook000
-lib/smalleiffel/short/html2/hook002
-lib/smalleiffel/short/html2/hook010
-lib/smalleiffel/short/html2/hook011
-lib/smalleiffel/short/html2/hook012
-lib/smalleiffel/short/html2/hook015
-lib/smalleiffel/short/html2/hook018
-lib/smalleiffel/short/html2/hook019
-lib/smalleiffel/short/html2/hook100
-lib/smalleiffel/short/html2/hook200
-lib/smalleiffel/short/html2/hook201
-lib/smalleiffel/short/html2/hook202
-lib/smalleiffel/short/html2/hook204
-lib/smalleiffel/short/html2/hook205
-lib/smalleiffel/short/html2/hook208
-lib/smalleiffel/short/html2/hook310
-lib/smalleiffel/short/html2/hook313
-lib/smalleiffel/short/html2/hook401
-lib/smalleiffel/short/html2/hook402
-lib/smalleiffel/short/html2/hook413
-lib/smalleiffel/short/html2/hook416
-lib/smalleiffel/short/html2/hook427
-lib/smalleiffel/short/html2/hook430
-lib/smalleiffel/short/html2/hook511
-lib/smalleiffel/short/html2/hook513
-lib/smalleiffel/short/html2/hook516
-lib/smalleiffel/short/html2/hook527
-lib/smalleiffel/short/html2/hook530
-lib/smalleiffel/short/html2/hook599
-lib/smalleiffel/short/html2/hook811
-lib/smalleiffel/short/html2/hook813
-lib/smalleiffel/short/html2/hook816
-lib/smalleiffel/short/html2/hook819
-lib/smalleiffel/short/html2/hook827
-lib/smalleiffel/short/html2/hook830
-lib/smalleiffel/short/html2/hook900
-lib/smalleiffel/short/html2/hook905
-lib/smalleiffel/short/html2/hook999
-lib/smalleiffel/short/html2/like
-lib/smalleiffel/short/html2/old
-lib/smalleiffel/short/html2/op_quote
-lib/smalleiffel/short/html2/op_strip
-lib/smalleiffel/short/plain/READ_ME
-lib/smalleiffel/short/tex1/READ_ME
-lib/smalleiffel/short/tex1/hook000
-lib/smalleiffel/short/tex1/hook999
-lib/smalleiffel/short/tex2/AECL
-lib/smalleiffel/short/tex2/Acn
-lib/smalleiffel/short/tex2/BECL
-lib/smalleiffel/short/tex2/Bcn
-lib/smalleiffel/short/tex2/READ_ME
-lib/smalleiffel/short/tex2/Uan
-lib/smalleiffel/short/tex2/Ucomment
-lib/smalleiffel/short/tex2/Usfn
-lib/smalleiffel/short/tex2/Utag
-lib/smalleiffel/short/tex2/cl_quote
-lib/smalleiffel/short/tex2/hook000
-lib/smalleiffel/short/tex2/hook013
-lib/smalleiffel/short/tex2/hook100
-lib/smalleiffel/short/tex2/hook200
-lib/smalleiffel/short/tex2/hook202
-lib/smalleiffel/short/tex2/hook204
-lib/smalleiffel/short/tex2/hook401
-lib/smalleiffel/short/tex2/hook402
-lib/smalleiffel/short/tex2/hook511
-lib/smalleiffel/short/tex2/hook811
-lib/smalleiffel/short/tex2/hook900
-lib/smalleiffel/short/tex2/hook904
-lib/smalleiffel/short/tex2/hook999
-lib/smalleiffel/short/tex2/op_quote
-lib/smalleiffel/short/tex2/rem
-lib/smalleiffel/short/tex3/AECL
-lib/smalleiffel/short/tex3/Aan
-lib/smalleiffel/short/tex3/Acn
-lib/smalleiffel/short/tex3/Asfn
-lib/smalleiffel/short/tex3/BECL
-lib/smalleiffel/short/tex3/Ban
-lib/smalleiffel/short/tex3/Bcn
-lib/smalleiffel/short/tex3/Bifn
-lib/smalleiffel/short/tex3/Bpfn
-lib/smalleiffel/short/tex3/Bsfn
-lib/smalleiffel/short/tex3/Current
-lib/smalleiffel/short/tex3/READ_ME
-lib/smalleiffel/short/tex3/Result
-lib/smalleiffel/short/tex3/Uan
-lib/smalleiffel/short/tex3/Ucomment
-lib/smalleiffel/short/tex3/Usfn
-lib/smalleiffel/short/tex3/Utag
-lib/smalleiffel/short/tex3/cl_quote
-lib/smalleiffel/short/tex3/close_sb
-lib/smalleiffel/short/tex3/hook000
-lib/smalleiffel/short/tex3/hook013
-lib/smalleiffel/short/tex3/hook100
-lib/smalleiffel/short/tex3/hook200
-lib/smalleiffel/short/tex3/hook204
-lib/smalleiffel/short/tex3/hook401
-lib/smalleiffel/short/tex3/hook402
-lib/smalleiffel/short/tex3/hook511
-lib/smalleiffel/short/tex3/hook811
-lib/smalleiffel/short/tex3/hook832
-lib/smalleiffel/short/tex3/hook900
-lib/smalleiffel/short/tex3/hook904
-lib/smalleiffel/short/tex3/hook999
-lib/smalleiffel/short/tex3/op_quote
-lib/smalleiffel/short/tex3/open_sb
-lib/smalleiffel/short/tex3/rem
-lib/smalleiffel/sys/READ_ME
-lib/smalleiffel/sys/compiler.se
-lib/smalleiffel/sys/gc
-lib/smalleiffel/sys/gc_lib/BeOS_x86.c
-lib/smalleiffel/sys/gc_lib/MacintoshPPC.c
-lib/smalleiffel/sys/gc_lib/aix.c
-lib/smalleiffel/sys/gc_lib/alpha.c
-lib/smalleiffel/sys/gc_lib/freebsd.c
-lib/smalleiffel/sys/gc_lib/generic.c
-lib/smalleiffel/sys/gc_lib/hp-pa.c
-lib/smalleiffel/sys/gc_lib/linux.c
-lib/smalleiffel/sys/gc_lib/m68k-amigaos.c
-lib/smalleiffel/sys/gc_lib/m68k.c
-lib/smalleiffel/sys/gc_lib/sparc.c
-lib/smalleiffel/sys/gc_lib/windows.c
-lib/smalleiffel/sys/loadpath.UNIX
-lib/smalleiffel/sys/runtime/SmallEiffelRuntime.class
-lib/smalleiffel/sys/runtime/SmallEiffelRuntime.java
-lib/smalleiffel/sys/runtime/base.h
-lib/smalleiffel/sys/runtime/basic_directory.c
-lib/smalleiffel/sys/runtime/basic_directory.h
-lib/smalleiffel/sys/runtime/boost.c
-lib/smalleiffel/sys/runtime/boost.h
-lib/smalleiffel/sys/runtime/exceptions.c
-lib/smalleiffel/sys/runtime/exceptions.h
-lib/smalleiffel/sys/runtime/gc_lib.c
-lib/smalleiffel/sys/runtime/gc_lib.h
-lib/smalleiffel/sys/runtime/no_check.c
-lib/smalleiffel/sys/runtime/no_check.h
-lib/smalleiffel/sys/runtime/trace.c
-lib/smalleiffel/sys/runtime/trace.h
-lib/smalleiffel/sys/system.se
-@dirrm lib/smalleiffel/sys/runtime
-@dirrm lib/smalleiffel/sys/gc_lib
-@dirrm lib/smalleiffel/sys
-@dirrm lib/smalleiffel/short/tex3
-@dirrm lib/smalleiffel/short/tex2
-@dirrm lib/smalleiffel/short/tex1
-@dirrm lib/smalleiffel/short/plain
-@dirrm lib/smalleiffel/short/html2
-@dirrm lib/smalleiffel/short/html1
-@dirrm lib/smalleiffel/short
-@dirrm lib/smalleiffel/man
-@dirrm lib/smalleiffel/lib_std
-@dirrm lib/smalleiffel/lib_show/parking
-@dirrm lib/smalleiffel/lib_show/lib_rand
-@dirrm lib/smalleiffel/lib_show/hanoi
-@dirrm lib/smalleiffel/lib_show/gcd
-@dirrm lib/smalleiffel/lib_show/external/JVM
-@dirrm lib/smalleiffel/lib_show/external/C
-@dirrm lib/smalleiffel/lib_show/external
-@dirrm lib/smalleiffel/lib_show/directory
-@dirrm lib/smalleiffel/lib_show/cecil/example8
-@dirrm lib/smalleiffel/lib_show/cecil/example7
-@dirrm lib/smalleiffel/lib_show/cecil/example6
-@dirrm lib/smalleiffel/lib_show/cecil/example5
-@dirrm lib/smalleiffel/lib_show/cecil/example4
-@dirrm lib/smalleiffel/lib_show/cecil/example3
-@dirrm lib/smalleiffel/lib_show/cecil/example2
-@dirrm lib/smalleiffel/lib_show/cecil/example1
-@dirrm lib/smalleiffel/lib_show/cecil/JVM
-@dirrm lib/smalleiffel/lib_show/cecil
-@dirrm lib/smalleiffel/lib_show/animal
-@dirrm lib/smalleiffel/lib_show
-@dirrm lib/smalleiffel/lib_se
-@dirrm lib/smalleiffel/lib_rand
-@dirrm lib/smalleiffel/contrib/lib
-@dirrm lib/smalleiffel/contrib/htmldoc
-@dirrm lib/smalleiffel/contrib/edb
-@dirrm lib/smalleiffel/contrib
-@dirrm lib/smalleiffel/bin
-@dirrm lib/smalleiffel
+libexec/smalleiffel/clean
+libexec/smalleiffel/compile
+libexec/smalleiffel/compile_to_c
+libexec/smalleiffel/compile_to_jvm
+libexec/smalleiffel/finder
+libexec/smalleiffel/pretty
+libexec/smalleiffel/print_jvm_class
+libexec/smalleiffel/short
+share/doc/smalleiffel/COPYING
+share/doc/smalleiffel/Eiffel.FAQ
+share/doc/smalleiffel/NOT_YET_IMPLEMENTED.txt
+share/doc/smalleiffel/SmallEiffelFAQ.html
+share/doc/smalleiffel/WeNeedFeedBack.txt
+share/doc/smalleiffel/c_code.html
+share/doc/smalleiffel/cecil.html
+share/doc/smalleiffel/clean.html
+share/doc/smalleiffel/compile.html
+share/doc/smalleiffel/compile_to_c.html
+share/doc/smalleiffel/compile_to_jvm.html
+share/doc/smalleiffel/external.html
+share/doc/smalleiffel/finder.html
+share/doc/smalleiffel/index.html
+share/doc/smalleiffel/pretty.html
+share/doc/smalleiffel/print_jvm_class.html
+share/doc/smalleiffel/se-line.gif
+share/doc/smalleiffel/short.html
+share/doc/smalleiffel/support.html
+share/doc/smalleiffel/system.html
+share/examples/smalleiffel/contrib/READ_ME
+share/examples/smalleiffel/contrib/edb/READ_ME
+share/examples/smalleiffel/contrib/edb/add-line-directive
+share/examples/smalleiffel/contrib/edb/edb.el
+share/examples/smalleiffel/contrib/edb/edb19.el
+share/examples/smalleiffel/contrib/edb/gc-inc
+share/examples/smalleiffel/contrib/edb/move-if-changed
+share/examples/smalleiffel/contrib/edb/sec
+share/examples/smalleiffel/contrib/htmldoc/READ_ME
+share/examples/smalleiffel/contrib/htmldoc/hooks.sh
+share/examples/smalleiffel/contrib/htmldoc/htmlshort
+share/examples/smalleiffel/contrib/lib/case_insensitive_string.e
+share/examples/smalleiffel/contrib/lib/header.txt
+share/examples/smalleiffel/contrib/lib/string_formatter.e
+share/examples/smalleiffel/lib_show/animal/animal.e
+share/examples/smalleiffel/lib_show/animal/chat.e
+share/examples/smalleiffel/lib_show/animal/chien.e
+share/examples/smalleiffel/lib_show/animal/mille_pattes.e
+share/examples/smalleiffel/lib_show/animal/quadrupede.e
+share/examples/smalleiffel/lib_show/animal/sample1.e
+share/examples/smalleiffel/lib_show/animal/sample2.e
+share/examples/smalleiffel/lib_show/animal/sample3.e
+share/examples/smalleiffel/lib_show/cecil/JVM/Example1.java
+share/examples/smalleiffel/lib_show/cecil/JVM/Example2.java
+share/examples/smalleiffel/lib_show/cecil/JVM/Example3.java
+share/examples/smalleiffel/lib_show/cecil/JVM/Example4.java
+share/examples/smalleiffel/lib_show/cecil/JVM/root2.e
+share/examples/smalleiffel/lib_show/cecil/JVM/root3.e
+share/examples/smalleiffel/lib_show/cecil/JVM/root4.e
+share/examples/smalleiffel/lib_show/cecil/READ_ME
+share/examples/smalleiffel/lib_show/cecil/example1/c_prog.c
+share/examples/smalleiffel/lib_show/cecil/example1/cecil.se
+share/examples/smalleiffel/lib_show/cecil/example1/example.e
+share/examples/smalleiffel/lib_show/cecil/example1/output
+share/examples/smalleiffel/lib_show/cecil/example2/c_prog.c
+share/examples/smalleiffel/lib_show/cecil/example2/cecil.se
+share/examples/smalleiffel/lib_show/cecil/example2/example.e
+share/examples/smalleiffel/lib_show/cecil/example2/output
+share/examples/smalleiffel/lib_show/cecil/example3/c_prog.c
+share/examples/smalleiffel/lib_show/cecil/example3/cecil.se
+share/examples/smalleiffel/lib_show/cecil/example3/example.e
+share/examples/smalleiffel/lib_show/cecil/example3/output
+share/examples/smalleiffel/lib_show/cecil/example4/animal.e
+share/examples/smalleiffel/lib_show/cecil/example4/c_prog.c
+share/examples/smalleiffel/lib_show/cecil/example4/cat.e
+share/examples/smalleiffel/lib_show/cecil/example4/cecil.se
+share/examples/smalleiffel/lib_show/cecil/example4/dog.e
+share/examples/smalleiffel/lib_show/cecil/example4/example.e
+share/examples/smalleiffel/lib_show/cecil/example4/output
+share/examples/smalleiffel/lib_show/cecil/example5/c_prog.c
+share/examples/smalleiffel/lib_show/cecil/example5/cecil.se
+share/examples/smalleiffel/lib_show/cecil/example5/example.e
+share/examples/smalleiffel/lib_show/cecil/example5/output
+share/examples/smalleiffel/lib_show/cecil/example6/c_prog.c
+share/examples/smalleiffel/lib_show/cecil/example6/cecil.se
+share/examples/smalleiffel/lib_show/cecil/example6/example.e
+share/examples/smalleiffel/lib_show/cecil/example6/output
+share/examples/smalleiffel/lib_show/cecil/example7/c_prog.c
+share/examples/smalleiffel/lib_show/cecil/example7/cecil.se
+share/examples/smalleiffel/lib_show/cecil/example7/example.e
+share/examples/smalleiffel/lib_show/cecil/example7/output
+share/examples/smalleiffel/lib_show/cecil/example8/c_factory.e
+share/examples/smalleiffel/lib_show/cecil/example8/c_prog.c
+share/examples/smalleiffel/lib_show/cecil/example8/cecil.se
+share/examples/smalleiffel/lib_show/cecil/example8/example.e
+share/examples/smalleiffel/lib_show/cecil/example8/output
+share/examples/smalleiffel/lib_show/directory/example01.e
+share/examples/smalleiffel/lib_show/directory/example01.h
+share/examples/smalleiffel/lib_show/directory/example01.make
+share/examples/smalleiffel/lib_show/directory/example011.c
+share/examples/smalleiffel/lib_show/directory/example012.c
+share/examples/smalleiffel/lib_show/directory/example013.c
+share/examples/smalleiffel/lib_show/directory/example02.e
+share/examples/smalleiffel/lib_show/directory/example03.e
+share/examples/smalleiffel/lib_show/directory/example03.h
+share/examples/smalleiffel/lib_show/directory/example03.make
+share/examples/smalleiffel/lib_show/directory/example031.c
+share/examples/smalleiffel/lib_show/directory/example032.c
+share/examples/smalleiffel/lib_show/external/C/READ_ME
+share/examples/smalleiffel/lib_show/external/C/address_of_demo.e
+share/examples/smalleiffel/lib_show/external/C/address_of_demo.out
+share/examples/smalleiffel/lib_show/external/C/address_of_src.c
+share/examples/smalleiffel/lib_show/external/C/external_demo.e
+share/examples/smalleiffel/lib_show/external/C/external_demo.out
+share/examples/smalleiffel/lib_show/external/C/external_src.c
+share/examples/smalleiffel/lib_show/external/JVM/example1.e
+share/examples/smalleiffel/lib_show/external/JVM/example1.out
+share/examples/smalleiffel/lib_show/external/JVM/example2.e
+share/examples/smalleiffel/lib_show/external/JVM/example2.out
+share/examples/smalleiffel/lib_show/external/READ_ME
+share/examples/smalleiffel/lib_show/fibonacci.e
+share/examples/smalleiffel/lib_show/gcd/integer.e
+share/examples/smalleiffel/lib_show/gcd/test_gcd.e
+share/examples/smalleiffel/lib_show/hanoi/hanoi.e
+share/examples/smalleiffel/lib_show/hanoi/tower.e
+share/examples/smalleiffel/lib_show/hello_world.e
+share/examples/smalleiffel/lib_show/knight.e
+share/examples/smalleiffel/lib_show/lib_rand/demo1.e
+share/examples/smalleiffel/lib_show/lib_rand/demo2.e
+share/examples/smalleiffel/lib_show/lib_rand/demo3.e
+share/examples/smalleiffel/lib_show/parking/command.e
+share/examples/smalleiffel/lib_show/parking/date.e
+share/examples/smalleiffel/lib_show/parking/level.e
+share/examples/smalleiffel/lib_show/parking/parking.e
+share/examples/smalleiffel/lib_show/parking/run_parking.e
+share/examples/smalleiffel/lib_show/parking/ticket.e
+share/examples/smalleiffel/lib_show/print_arguments.e
+share/examples/smalleiffel/lib_show/pyramid.e
+share/examples/smalleiffel/lib_show/pyramid2.e
+share/examples/smalleiffel/lib_show/spread_illness.e
+share/smalleiffel/lib_rand/READ_ME
+share/smalleiffel/lib_rand/gen_rand.e
+share/smalleiffel/lib_rand/min_stand.e
+share/smalleiffel/lib_rand/std_rand.e
+share/smalleiffel/lib_se/abstract_current.e
+share/smalleiffel/lib_se/abstract_result.e
+share/smalleiffel/lib_se/address_of.e
+share/smalleiffel/lib_se/address_of_pool.e
+share/smalleiffel/lib_se/aliased_string_list.e
+share/smalleiffel/lib_se/argument_name.e
+share/smalleiffel/lib_se/argument_name1.e
+share/smalleiffel/lib_se/argument_name2.e
+share/smalleiffel/lib_se/assertion.e
+share/smalleiffel/lib_se/assertion_collector.e
+share/smalleiffel/lib_se/assertion_list.e
+share/smalleiffel/lib_se/assignment.e
+share/smalleiffel/lib_se/attribute.e
+share/smalleiffel/lib_se/base_class.e
+share/smalleiffel/lib_se/base_type_constant.e
+share/smalleiffel/lib_se/binary_file_read.e
+share/smalleiffel/lib_se/binary_file_write.e
+share/smalleiffel/lib_se/bit_constant.e
+share/smalleiffel/lib_se/boolean_constant.e
+share/smalleiffel/lib_se/c_pretty_printer.e
+share/smalleiffel/lib_se/call.e
+share/smalleiffel/lib_se/call_0.e
+share/smalleiffel/lib_se/call_0_c.e
+share/smalleiffel/lib_se/call_1.e
+share/smalleiffel/lib_se/call_1_c.e
+share/smalleiffel/lib_se/call_infix.e
+share/smalleiffel/lib_se/call_infix1.e
+share/smalleiffel/lib_se/call_infix2.e
+share/smalleiffel/lib_se/call_infix_and.e
+share/smalleiffel/lib_se/call_infix_and_then.e
+share/smalleiffel/lib_se/call_infix_div.e
+share/smalleiffel/lib_se/call_infix_eq.e
+share/smalleiffel/lib_se/call_infix_freeop.e
+share/smalleiffel/lib_se/call_infix_ge.e
+share/smalleiffel/lib_se/call_infix_gt.e
+share/smalleiffel/lib_se/call_infix_implies.e
+share/smalleiffel/lib_se/call_infix_int_div.e
+share/smalleiffel/lib_se/call_infix_int_rem.e
+share/smalleiffel/lib_se/call_infix_le.e
+share/smalleiffel/lib_se/call_infix_lt.e
+share/smalleiffel/lib_se/call_infix_minus.e
+share/smalleiffel/lib_se/call_infix_neq.e
+share/smalleiffel/lib_se/call_infix_or.e
+share/smalleiffel/lib_se/call_infix_or_else.e
+share/smalleiffel/lib_se/call_infix_plus.e
+share/smalleiffel/lib_se/call_infix_power.e
+share/smalleiffel/lib_se/call_infix_times.e
+share/smalleiffel/lib_se/call_infix_xor.e
+share/smalleiffel/lib_se/call_n.e
+share/smalleiffel/lib_se/call_prefix.e
+share/smalleiffel/lib_se/call_prefix_freeop.e
+share/smalleiffel/lib_se/call_prefix_minus.e
+share/smalleiffel/lib_se/call_prefix_not.e
+share/smalleiffel/lib_se/call_prefix_plus.e
+share/smalleiffel/lib_se/call_proc_call.e
+share/smalleiffel/lib_se/cecil_arg_list.e
+share/smalleiffel/lib_se/cecil_pool.e
+share/smalleiffel/lib_se/cecil_target.e
+share/smalleiffel/lib_se/character_constant.e
+share/smalleiffel/lib_se/check_invariant.e
+share/smalleiffel/lib_se/class_invariant.e
+share/smalleiffel/lib_se/class_name.e
+share/smalleiffel/lib_se/class_name_list.e
+share/smalleiffel/lib_se/clean.e
+share/smalleiffel/lib_se/client_list.e
+share/smalleiffel/lib_se/code_attribute.e
+share/smalleiffel/lib_se/code_printer.e
+share/smalleiffel/lib_se/command_flags.e
+share/smalleiffel/lib_se/comment.e
+share/smalleiffel/lib_se/compile.e
+share/smalleiffel/lib_se/compile_to_c.e
+share/smalleiffel/lib_se/compile_to_jvm.e
+share/smalleiffel/lib_se/compound.e
+share/smalleiffel/lib_se/constant_pool.e
+share/smalleiffel/lib_se/cp_info.e
+share/smalleiffel/lib_se/cp_info_tags.e
+share/smalleiffel/lib_se/creation_call.e
+share/smalleiffel/lib_se/creation_call_1.e
+share/smalleiffel/lib_se/creation_call_1_2.e
+share/smalleiffel/lib_se/creation_call_2.e
+share/smalleiffel/lib_se/creation_call_2_4.e
+share/smalleiffel/lib_se/creation_call_3.e
+share/smalleiffel/lib_se/creation_call_3_4.e
+share/smalleiffel/lib_se/creation_call_4.e
+share/smalleiffel/lib_se/creation_clause.e
+share/smalleiffel/lib_se/creation_clause_list.e
+share/smalleiffel/lib_se/cst_att.e
+share/smalleiffel/lib_se/cst_att_bit.e
+share/smalleiffel/lib_se/cst_att_boolean.e
+share/smalleiffel/lib_se/cst_att_character.e
+share/smalleiffel/lib_se/cst_att_double.e
+share/smalleiffel/lib_se/cst_att_integer.e
+share/smalleiffel/lib_se/cst_att_real.e
+share/smalleiffel/lib_se/cst_att_string.e
+share/smalleiffel/lib_se/cst_att_unique.e
+share/smalleiffel/lib_se/declaration.e
+share/smalleiffel/lib_se/declaration_1.e
+share/smalleiffel/lib_se/declaration_group.e
+share/smalleiffel/lib_se/declaration_list.e
+share/smalleiffel/lib_se/deferred_function.e
+share/smalleiffel/lib_se/deferred_procedure.e
+share/smalleiffel/lib_se/deferred_routine.e
+share/smalleiffel/lib_se/e_check.e
+share/smalleiffel/lib_se/e_debug.e
+share/smalleiffel/lib_se/e_ensure.e
+share/smalleiffel/lib_se/e_false.e
+share/smalleiffel/lib_se/e_feature.e
+share/smalleiffel/lib_se/e_inspect.e
+share/smalleiffel/lib_se/e_loop.e
+share/smalleiffel/lib_se/e_old.e
+share/smalleiffel/lib_se/e_precursor.e
+share/smalleiffel/lib_se/e_precursor_function.e
+share/smalleiffel/lib_se/e_precursor_procedure.e
+share/smalleiffel/lib_se/e_require.e
+share/smalleiffel/lib_se/e_retry.e
+share/smalleiffel/lib_se/e_strip.e
+share/smalleiffel/lib_se/e_true.e
+share/smalleiffel/lib_se/e_void.e
+share/smalleiffel/lib_se/e_when.e
+share/smalleiffel/lib_se/echo.e
+share/smalleiffel/lib_se/effective_arg_list.e
+share/smalleiffel/lib_se/effective_routine.e
+share/smalleiffel/lib_se/eiffel_parser.e
+share/smalleiffel/lib_se/error_handler.e
+share/smalleiffel/lib_se/exception_table.e
+share/smalleiffel/lib_se/exceptions_handler.e
+share/smalleiffel/lib_se/export_item.e
+share/smalleiffel/lib_se/export_list.e
+share/smalleiffel/lib_se/expression.e
+share/smalleiffel/lib_se/expression_with_comment.e
+share/smalleiffel/lib_se/external_function.e
+share/smalleiffel/lib_se/external_procedure.e
+share/smalleiffel/lib_se/external_routine.e
+share/smalleiffel/lib_se/feature_clause.e
+share/smalleiffel/lib_se/feature_clause_list.e
+share/smalleiffel/lib_se/feature_name.e
+share/smalleiffel/lib_se/feature_name_list.e
+share/smalleiffel/lib_se/field_info.e
+share/smalleiffel/lib_se/finder.e
+share/smalleiffel/lib_se/fmt.e
+share/smalleiffel/lib_se/formal_arg_list.e
+share/smalleiffel/lib_se/formal_generic_arg.e
+share/smalleiffel/lib_se/formal_generic_list.e
+share/smalleiffel/lib_se/frozen_feature_name.e
+share/smalleiffel/lib_se/frozen_string_list.e
+share/smalleiffel/lib_se/function.e
+share/smalleiffel/lib_se/gc_handler.e
+share/smalleiffel/lib_se/globals.e
+share/smalleiffel/lib_se/id_provider.e
+share/smalleiffel/lib_se/if_globals.e
+share/smalleiffel/lib_se/ifthen.e
+share/smalleiffel/lib_se/ifthenelse.e
+share/smalleiffel/lib_se/ifthenlist.e
+share/smalleiffel/lib_se/implicit_cast.e
+share/smalleiffel/lib_se/implicit_current.e
+share/smalleiffel/lib_se/index_clause.e
+share/smalleiffel/lib_se/index_list.e
+share/smalleiffel/lib_se/infix_name.e
+share/smalleiffel/lib_se/install.e
+share/smalleiffel/lib_se/instruction.e
+share/smalleiffel/lib_se/instruction_with_comment.e
+share/smalleiffel/lib_se/integer_constant.e
+share/smalleiffel/lib_se/jvm.e
+share/smalleiffel/lib_se/local_argument.e
+share/smalleiffel/lib_se/local_argument1.e
+share/smalleiffel/lib_se/local_name.e
+share/smalleiffel/lib_se/local_name1.e
+share/smalleiffel/lib_se/local_name2.e
+share/smalleiffel/lib_se/local_var_list.e
+share/smalleiffel/lib_se/loop_invariant.e
+share/smalleiffel/lib_se/loop_variant.e
+share/smalleiffel/lib_se/loop_variant_1.e
+share/smalleiffel/lib_se/loop_variant_2.e
+share/smalleiffel/lib_se/manifest_array.e
+share/smalleiffel/lib_se/manifest_array_pool.e
+share/smalleiffel/lib_se/manifest_string.e
+share/smalleiffel/lib_se/manifest_string_pool.e
+share/smalleiffel/lib_se/method_info.e
+share/smalleiffel/lib_se/name.e
+share/smalleiffel/lib_se/native.e
+share/smalleiffel/lib_se/native_c.e
+share/smalleiffel/lib_se/native_inline_with_current.e
+share/smalleiffel/lib_se/native_inline_without_current.e
+share/smalleiffel/lib_se/native_jvm.e
+share/smalleiffel/lib_se/native_jvm_invokestatic.e
+share/smalleiffel/lib_se/native_jvm_invokevirtual.e
+share/smalleiffel/lib_se/native_small_eiffel.e
+share/smalleiffel/lib_se/native_with_current.e
+share/smalleiffel/lib_se/native_without_current.e
+share/smalleiffel/lib_se/once_function.e
+share/smalleiffel/lib_se/once_procedure.e
+share/smalleiffel/lib_se/once_result.e
+share/smalleiffel/lib_se/once_routine.e
+share/smalleiffel/lib_se/once_routine_pool.e
+share/smalleiffel/lib_se/ordinary_result.e
+share/smalleiffel/lib_se/parent.e
+share/smalleiffel/lib_se/parent_list.e
+share/smalleiffel/lib_se/parser_buffer.e
+share/smalleiffel/lib_se/position.e
+share/smalleiffel/lib_se/precursor_name.e
+share/smalleiffel/lib_se/prefix_name.e
+share/smalleiffel/lib_se/pretty.e
+share/smalleiffel/lib_se/print_jvm_class.e
+share/smalleiffel/lib_se/proc_call.e
+share/smalleiffel/lib_se/proc_call_0.e
+share/smalleiffel/lib_se/proc_call_1.e
+share/smalleiffel/lib_se/proc_call_n.e
+share/smalleiffel/lib_se/procedure.e
+share/smalleiffel/lib_se/real_constant.e
+share/smalleiffel/lib_se/rename_list.e
+share/smalleiffel/lib_se/rename_pair.e
+share/smalleiffel/lib_se/reverse_assignment.e
+share/smalleiffel/lib_se/routine.e
+share/smalleiffel/lib_se/run_class.e
+share/smalleiffel/lib_se/run_control.e
+share/smalleiffel/lib_se/run_feature.e
+share/smalleiffel/lib_se/run_feature_1.e
+share/smalleiffel/lib_se/run_feature_10.e
+share/smalleiffel/lib_se/run_feature_11.e
+share/smalleiffel/lib_se/run_feature_2.e
+share/smalleiffel/lib_se/run_feature_3.e
+share/smalleiffel/lib_se/run_feature_4.e
+share/smalleiffel/lib_se/run_feature_5.e
+share/smalleiffel/lib_se/run_feature_6.e
+share/smalleiffel/lib_se/run_feature_7.e
+share/smalleiffel/lib_se/run_feature_8.e
+share/smalleiffel/lib_se/run_feature_9.e
+share/smalleiffel/lib_se/run_require.e
+share/smalleiffel/lib_se/same_executables.e
+share/smalleiffel/lib_se/short.e
+share/smalleiffel/lib_se/short_print.e
+share/smalleiffel/lib_se/simple_feature_name.e
+share/smalleiffel/lib_se/small_eiffel.e
+share/smalleiffel/lib_se/string_aliaser.e
+share/smalleiffel/lib_se/switch.e
+share/smalleiffel/lib_se/switch_collection.e
+share/smalleiffel/lib_se/system_tools.e
+share/smalleiffel/lib_se/tag_name.e
+share/smalleiffel/lib_se/tmp_feature.e
+share/smalleiffel/lib_se/tmp_name.e
+share/smalleiffel/lib_se/type.e
+share/smalleiffel/lib_se/type_anchored.e
+share/smalleiffel/lib_se/type_any.e
+share/smalleiffel/lib_se/type_array.e
+share/smalleiffel/lib_se/type_basic_eiffel_expanded.e
+share/smalleiffel/lib_se/type_bit.e
+share/smalleiffel/lib_se/type_bit_1.e
+share/smalleiffel/lib_se/type_bit_2.e
+share/smalleiffel/lib_se/type_bit_ref.e
+share/smalleiffel/lib_se/type_boolean.e
+share/smalleiffel/lib_se/type_character.e
+share/smalleiffel/lib_se/type_class.e
+share/smalleiffel/lib_se/type_double.e
+share/smalleiffel/lib_se/type_expanded.e
+share/smalleiffel/lib_se/type_formal_generic.e
+share/smalleiffel/lib_se/type_generic.e
+share/smalleiffel/lib_se/type_integer.e
+share/smalleiffel/lib_se/type_like_argument.e
+share/smalleiffel/lib_se/type_like_current.e
+share/smalleiffel/lib_se/type_like_feature.e
+share/smalleiffel/lib_se/type_native_array.e
+share/smalleiffel/lib_se/type_none.e
+share/smalleiffel/lib_se/type_pointer.e
+share/smalleiffel/lib_se/type_real.e
+share/smalleiffel/lib_se/type_ref_to_exp.e
+share/smalleiffel/lib_se/type_string.e
+share/smalleiffel/lib_se/when_item.e
+share/smalleiffel/lib_se/when_item_1.e
+share/smalleiffel/lib_se/when_item_2.e
+share/smalleiffel/lib_se/when_list.e
+share/smalleiffel/lib_se/writable_attribute.e
+share/smalleiffel/lib_se/written_current.e
+share/smalleiffel/lib_std/any.e
+share/smalleiffel/lib_std/arguments.e
+share/smalleiffel/lib_std/array.e
+share/smalleiffel/lib_std/array2.e
+share/smalleiffel/lib_std/arrayed_collection.e
+share/smalleiffel/lib_std/basic_directory.e
+share/smalleiffel/lib_std/bit_n.e
+share/smalleiffel/lib_std/bit_n_ref.e
+share/smalleiffel/lib_std/bit_string.e
+share/smalleiffel/lib_std/boolean.e
+share/smalleiffel/lib_std/boolean_ref.e
+share/smalleiffel/lib_std/character.e
+share/smalleiffel/lib_std/character_ref.e
+share/smalleiffel/lib_std/collection.e
+share/smalleiffel/lib_std/collection2.e
+share/smalleiffel/lib_std/collection_sorter.e
+share/smalleiffel/lib_std/comparable.e
+share/smalleiffel/lib_std/counter.e
+share/smalleiffel/lib_std/dictionary.e
+share/smalleiffel/lib_std/directory.e
+share/smalleiffel/lib_std/dirent.e
+share/smalleiffel/lib_std/double.e
+share/smalleiffel/lib_std/double_ref.e
+share/smalleiffel/lib_std/exceptions.e
+share/smalleiffel/lib_std/file_tools.e
+share/smalleiffel/lib_std/fixed_array.e
+share/smalleiffel/lib_std/fixed_array2.e
+share/smalleiffel/lib_std/general.e
+share/smalleiffel/lib_std/hashable.e
+share/smalleiffel/lib_std/input_stream.e
+share/smalleiffel/lib_std/integer.e
+share/smalleiffel/lib_std/integer_ref.e
+share/smalleiffel/lib_std/link.e
+share/smalleiffel/lib_std/link2.e
+share/smalleiffel/lib_std/link2_list.e
+share/smalleiffel/lib_std/link_list.e
+share/smalleiffel/lib_std/linked_collection.e
+share/smalleiffel/lib_std/linked_list.e
+share/smalleiffel/lib_std/memo.e
+share/smalleiffel/lib_std/memory.e
+share/smalleiffel/lib_std/native_array.e
+share/smalleiffel/lib_std/numeric.e
+share/smalleiffel/lib_std/output_stream.e
+share/smalleiffel/lib_std/platform.e
+share/smalleiffel/lib_std/pointer.e
+share/smalleiffel/lib_std/pointer_ref.e
+share/smalleiffel/lib_std/real.e
+share/smalleiffel/lib_std/real_ref.e
+share/smalleiffel/lib_std/reverse_collection_sorter.e
+share/smalleiffel/lib_std/std_error.e
+share/smalleiffel/lib_std/std_file_read.e
+share/smalleiffel/lib_std/std_file_read_write.e
+share/smalleiffel/lib_std/std_file_write.e
+share/smalleiffel/lib_std/std_input.e
+share/smalleiffel/lib_std/std_input_output.e
+share/smalleiffel/lib_std/std_output.e
+share/smalleiffel/lib_std/string.e
+share/smalleiffel/lib_std/two_way_linked_list.e
+share/smalleiffel/short/READ_ME
+share/smalleiffel/short/html1/Acn
+share/smalleiffel/short/html1/Bcn
+share/smalleiffel/short/html1/HOOKS.SH
+share/smalleiffel/short/html1/Mcn
+share/smalleiffel/short/html1/READ_ME
+share/smalleiffel/short/html1/cl_quote
+share/smalleiffel/short/html1/hook000
+share/smalleiffel/short/html1/hook002
+share/smalleiffel/short/html1/hook010
+share/smalleiffel/short/html1/hook011
+share/smalleiffel/short/html1/hook012
+share/smalleiffel/short/html1/hook015
+share/smalleiffel/short/html1/hook018
+share/smalleiffel/short/html1/hook019
+share/smalleiffel/short/html1/hook100
+share/smalleiffel/short/html1/hook200
+share/smalleiffel/short/html1/hook201
+share/smalleiffel/short/html1/hook202
+share/smalleiffel/short/html1/hook204
+share/smalleiffel/short/html1/hook205
+share/smalleiffel/short/html1/hook208
+share/smalleiffel/short/html1/hook310
+share/smalleiffel/short/html1/hook313
+share/smalleiffel/short/html1/hook401
+share/smalleiffel/short/html1/hook402
+share/smalleiffel/short/html1/hook413
+share/smalleiffel/short/html1/hook416
+share/smalleiffel/short/html1/hook427
+share/smalleiffel/short/html1/hook430
+share/smalleiffel/short/html1/hook511
+share/smalleiffel/short/html1/hook513
+share/smalleiffel/short/html1/hook516
+share/smalleiffel/short/html1/hook527
+share/smalleiffel/short/html1/hook530
+share/smalleiffel/short/html1/hook599
+share/smalleiffel/short/html1/hook811
+share/smalleiffel/short/html1/hook813
+share/smalleiffel/short/html1/hook816
+share/smalleiffel/short/html1/hook827
+share/smalleiffel/short/html1/hook830
+share/smalleiffel/short/html1/hook900
+share/smalleiffel/short/html1/hook905
+share/smalleiffel/short/html1/hook999
+share/smalleiffel/short/html1/op_quote
+share/smalleiffel/short/html2/!
+share/smalleiffel/short/html2/Acn
+share/smalleiffel/short/html2/Bcn
+share/smalleiffel/short/html2/Current
+share/smalleiffel/short/html2/HOOKS.SH
+share/smalleiffel/short/html2/Mcn
+share/smalleiffel/short/html2/READ_ME
+share/smalleiffel/short/html2/Result
+share/smalleiffel/short/html2/Void
+share/smalleiffel/short/html2/cl_quote
+share/smalleiffel/short/html2/hook000
+share/smalleiffel/short/html2/hook002
+share/smalleiffel/short/html2/hook010
+share/smalleiffel/short/html2/hook011
+share/smalleiffel/short/html2/hook012
+share/smalleiffel/short/html2/hook015
+share/smalleiffel/short/html2/hook018
+share/smalleiffel/short/html2/hook019
+share/smalleiffel/short/html2/hook100
+share/smalleiffel/short/html2/hook200
+share/smalleiffel/short/html2/hook201
+share/smalleiffel/short/html2/hook202
+share/smalleiffel/short/html2/hook204
+share/smalleiffel/short/html2/hook205
+share/smalleiffel/short/html2/hook208
+share/smalleiffel/short/html2/hook310
+share/smalleiffel/short/html2/hook313
+share/smalleiffel/short/html2/hook401
+share/smalleiffel/short/html2/hook402
+share/smalleiffel/short/html2/hook413
+share/smalleiffel/short/html2/hook416
+share/smalleiffel/short/html2/hook427
+share/smalleiffel/short/html2/hook430
+share/smalleiffel/short/html2/hook511
+share/smalleiffel/short/html2/hook513
+share/smalleiffel/short/html2/hook516
+share/smalleiffel/short/html2/hook527
+share/smalleiffel/short/html2/hook530
+share/smalleiffel/short/html2/hook599
+share/smalleiffel/short/html2/hook811
+share/smalleiffel/short/html2/hook813
+share/smalleiffel/short/html2/hook816
+share/smalleiffel/short/html2/hook819
+share/smalleiffel/short/html2/hook827
+share/smalleiffel/short/html2/hook830
+share/smalleiffel/short/html2/hook900
+share/smalleiffel/short/html2/hook905
+share/smalleiffel/short/html2/hook999
+share/smalleiffel/short/html2/like
+share/smalleiffel/short/html2/old
+share/smalleiffel/short/html2/op_quote
+share/smalleiffel/short/html2/op_strip
+share/smalleiffel/short/plain/READ_ME
+share/smalleiffel/short/tex1/READ_ME
+share/smalleiffel/short/tex1/hook000
+share/smalleiffel/short/tex1/hook999
+share/smalleiffel/short/tex2/AECL
+share/smalleiffel/short/tex2/Acn
+share/smalleiffel/short/tex2/BECL
+share/smalleiffel/short/tex2/Bcn
+share/smalleiffel/short/tex2/READ_ME
+share/smalleiffel/short/tex2/Uan
+share/smalleiffel/short/tex2/Ucomment
+share/smalleiffel/short/tex2/Usfn
+share/smalleiffel/short/tex2/Utag
+share/smalleiffel/short/tex2/cl_quote
+share/smalleiffel/short/tex2/hook000
+share/smalleiffel/short/tex2/hook013
+share/smalleiffel/short/tex2/hook100
+share/smalleiffel/short/tex2/hook200
+share/smalleiffel/short/tex2/hook202
+share/smalleiffel/short/tex2/hook204
+share/smalleiffel/short/tex2/hook401
+share/smalleiffel/short/tex2/hook402
+share/smalleiffel/short/tex2/hook511
+share/smalleiffel/short/tex2/hook811
+share/smalleiffel/short/tex2/hook900
+share/smalleiffel/short/tex2/hook904
+share/smalleiffel/short/tex2/hook999
+share/smalleiffel/short/tex2/op_quote
+share/smalleiffel/short/tex2/rem
+share/smalleiffel/short/tex3/AECL
+share/smalleiffel/short/tex3/Aan
+share/smalleiffel/short/tex3/Acn
+share/smalleiffel/short/tex3/Asfn
+share/smalleiffel/short/tex3/BECL
+share/smalleiffel/short/tex3/Ban
+share/smalleiffel/short/tex3/Bcn
+share/smalleiffel/short/tex3/Bifn
+share/smalleiffel/short/tex3/Bpfn
+share/smalleiffel/short/tex3/Bsfn
+share/smalleiffel/short/tex3/Current
+share/smalleiffel/short/tex3/READ_ME
+share/smalleiffel/short/tex3/Result
+share/smalleiffel/short/tex3/Uan
+share/smalleiffel/short/tex3/Ucomment
+share/smalleiffel/short/tex3/Usfn
+share/smalleiffel/short/tex3/Utag
+share/smalleiffel/short/tex3/cl_quote
+share/smalleiffel/short/tex3/close_sb
+share/smalleiffel/short/tex3/hook000
+share/smalleiffel/short/tex3/hook013
+share/smalleiffel/short/tex3/hook100
+share/smalleiffel/short/tex3/hook200
+share/smalleiffel/short/tex3/hook204
+share/smalleiffel/short/tex3/hook401
+share/smalleiffel/short/tex3/hook402
+share/smalleiffel/short/tex3/hook511
+share/smalleiffel/short/tex3/hook811
+share/smalleiffel/short/tex3/hook832
+share/smalleiffel/short/tex3/hook900
+share/smalleiffel/short/tex3/hook904
+share/smalleiffel/short/tex3/hook999
+share/smalleiffel/short/tex3/op_quote
+share/smalleiffel/short/tex3/open_sb
+share/smalleiffel/short/tex3/rem
+share/smalleiffel/sys/READ_ME
+share/smalleiffel/sys/compiler.se
+share/smalleiffel/sys/gc
+share/smalleiffel/sys/gc_lib/BeOS_x86.c
+share/smalleiffel/sys/gc_lib/MacintoshPPC.c
+share/smalleiffel/sys/gc_lib/aix.c
+share/smalleiffel/sys/gc_lib/alpha.c
+share/smalleiffel/sys/gc_lib/freebsd.c
+share/smalleiffel/sys/gc_lib/generic.c
+share/smalleiffel/sys/gc_lib/hp-pa.c
+share/smalleiffel/sys/gc_lib/linux.c
+share/smalleiffel/sys/gc_lib/m68k-amigaos.c
+share/smalleiffel/sys/gc_lib/m68k.c
+share/smalleiffel/sys/gc_lib/sparc.c
+share/smalleiffel/sys/gc_lib/windows.c
+share/smalleiffel/sys/loadpath.UNIX
+share/smalleiffel/sys/runtime/SmallEiffelRuntime.class
+share/smalleiffel/sys/runtime/SmallEiffelRuntime.java
+share/smalleiffel/sys/runtime/base.h
+share/smalleiffel/sys/runtime/basic_directory.c
+share/smalleiffel/sys/runtime/basic_directory.h
+share/smalleiffel/sys/runtime/boost.c
+share/smalleiffel/sys/runtime/boost.h
+share/smalleiffel/sys/runtime/exceptions.c
+share/smalleiffel/sys/runtime/exceptions.h
+share/smalleiffel/sys/runtime/gc_lib.c
+share/smalleiffel/sys/runtime/gc_lib.h
+share/smalleiffel/sys/runtime/no_check.c
+share/smalleiffel/sys/runtime/no_check.h
+share/smalleiffel/sys/runtime/trace.c
+share/smalleiffel/sys/runtime/trace.h
+share/smalleiffel/sys/system.se
+@dirrm share/smalleiffel/sys/runtime
+@dirrm share/smalleiffel/sys/gc_lib
+@dirrm share/smalleiffel/sys
+@dirrm share/smalleiffel/short/tex3
+@dirrm share/smalleiffel/short/tex2
+@dirrm share/smalleiffel/short/tex1
+@dirrm share/smalleiffel/short/plain
+@dirrm share/smalleiffel/short/html2
+@dirrm share/smalleiffel/short/html1
+@dirrm share/smalleiffel/short
+@dirrm share/smalleiffel/lib_std
+@dirrm share/smalleiffel/lib_se
+@dirrm share/smalleiffel/lib_rand
+@dirrm share/smalleiffel
+@dirrm share/examples/smalleiffel/lib_show/parking
+@dirrm share/examples/smalleiffel/lib_show/lib_rand
+@dirrm share/examples/smalleiffel/lib_show/hanoi
+@dirrm share/examples/smalleiffel/lib_show/gcd
+@dirrm share/examples/smalleiffel/lib_show/external/JVM
+@dirrm share/examples/smalleiffel/lib_show/external/C
+@dirrm share/examples/smalleiffel/lib_show/external
+@dirrm share/examples/smalleiffel/lib_show/directory
+@dirrm share/examples/smalleiffel/lib_show/cecil/example8
+@dirrm share/examples/smalleiffel/lib_show/cecil/example7
+@dirrm share/examples/smalleiffel/lib_show/cecil/example6
+@dirrm share/examples/smalleiffel/lib_show/cecil/example5
+@dirrm share/examples/smalleiffel/lib_show/cecil/example4
+@dirrm share/examples/smalleiffel/lib_show/cecil/example3
+@dirrm share/examples/smalleiffel/lib_show/cecil/example2
+@dirrm share/examples/smalleiffel/lib_show/cecil/example1
+@dirrm share/examples/smalleiffel/lib_show/cecil/JVM
+@dirrm share/examples/smalleiffel/lib_show/cecil
+@dirrm share/examples/smalleiffel/lib_show/animal
+@dirrm share/examples/smalleiffel/lib_show
+@dirrm share/examples/smalleiffel/contrib/lib
+@dirrm share/examples/smalleiffel/contrib/htmldoc
+@dirrm share/examples/smalleiffel/contrib/edb
+@dirrm share/examples/smalleiffel/contrib
+@dirrm share/examples/smalleiffel
+@dirrm share/doc/smalleiffel
+@dirrm libexec/smalleiffel
diff --git a/lang/smalleiffel/files/smalleiffel.sh b/lang/smalleiffel/files/smalleiffel.sh
index a1495bf4006..577731ed9e2 100644
--- a/lang/smalleiffel/files/smalleiffel.sh
+++ b/lang/smalleiffel/files/smalleiffel.sh
@@ -1,19 +1,29 @@
#!/bin/sh
#
-# $NetBSD: smalleiffel.sh,v 1.2 1999/06/21 21:23:16 jlam Exp $
+# $NetBSD: smalleiffel.sh,v 1.3 1999/10/12 08:01:33 jlam Exp $
#
# This script is invoked as:
#
# smalleiffel <cmd> [<arg> ...]
#
# where <cmd> is one of the programs in @@SE@@/bin.
#
-SMALLEIFFEL=@@SE@@; export SMALLEIFFEL
-SmallEiffel=${SMALLEIFFEL}/sys/system.se ; export SmallEiffel
-se_cmd=${SMALLEIFFEL}/bin/$1
+SMALLEIFFEL=@@SE_LIB@@; export SMALLEIFFEL
+SmallEiffel=${SMALLEIFFEL}/sys/system.se; export SmallEiffel
+se_cmd=@@SE_LIBEXEC@@/$1
+shift
+
+# Load the personal SmallEiffel environment from ${HOME}/.smalleiffelrc.
+# This file is the right place to define new environment variables used
+# by 3rd-party libraries, e.g. GOBO=/usr/pkg/share/gobo-eiffel.
+#
+if [ -f ${HOME}/.smalleiffelrc ]
+then
+ . ${HOME}/.smalleiffelrc
+fi
+
if [ -x ${se_cmd} ]
then
- shift
exec ${se_cmd} ${1+$@}
else
echo "smalleiffel: command ${se_cmd} not found."
@@ -1,19 +1,29 @@
# smalleiffel <cmd> [<arg> ...]
#
-# where <cmd> is one of the programs in @@SE@@/bin.
+# where <cmd> is one of the programs in @@SE_LIBEXEC@@.
#